@@ -21,7 +21,8 @@ from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
 from calculate.update.update import UpdateError
 from calculate.update.emerge_parser import EmergeError
-from calculate.lib.utils.portage import (GitError, EmergeLog,
+from calculate.lib.utils.git import GitError
+from calculate.lib.utils.portage import (EmergeLog,
                                          EmergeLogNamedTask, PackageList)
 from calculate.update.update_tasks import EmergeMark
 
